@@ -4,7 +4,7 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.47.0")
+(defparameter *autoconf-version* "5.49.0")
 (defparameter *autoconf-libdir* "/usr/lib64")
 (defparameter *autoconf-libexecdir* "/usr/libexec")
 (defparameter *autoconf-datadir* "/usr/share")
@@ -20,5 +20,5 @@
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/var/tmp/portage/sci-mathematics/maxima-5.47.0-r2/work/maxima-5.47.0")
+(defparameter *maxima-source-root* "/var/tmp/portage/sci-mathematics/maxima-5.49.0/work/maxima-5.49.0")
 (defparameter *maxima-default-layout-autotools* "true")
